@@ -4,8 +4,6 @@ import abc
 import cassandra
 from cassandra.cluster import Cluster
 import collections
-import json
-import re
 import sys
 
 import compression
@@ -15,10 +13,19 @@ from gemini_utils import (OrderedDict, itersubclasses, partition_by_fn)
 from sql_utils import ensure_columns
 from collections import namedtuple
 from geminicassandra.query_expressions import Basic_expression, AND_expression,\
-    NOT_expression, OR_expression, rows_as_set, GT_wildcard_expression
+    NOT_expression, OR_expression, async_rows_as_set, GT_wildcard_expression
 from geminicassandra.sql_utils import get_query_parts
 from cassandra.query import ordered_dict_factory, tuple_factory
 from string import strip
+import time
+from threading import Event
+from itertools import repeat, count
+from multiprocessing.process import Process
+from multiprocessing import Pipe, cpu_count
+from signal import signal, SIGPIPE, SIG_DFL
+import os
+from random import randint
+from time import sleep
 
 
 # geminicassandra imports
@@ -79,252 +86,7 @@ class DefaultRowFormat(RowFormat):
         """ return a header for the row """
         return "\t".join(fields)
 
-class CarrierSummary(RowFormat):
-    """
-    Generates a count of the carrier/noncarrier status of each feature in a given
-    column of the sample table
 
-    Assumes None == unknown.
-    """
-    name = "carrier_summary"
-
-    def __init__(self, args):
-        subjects = get_subjects(args)
-        self.carrier_summary = args.carrier_summary
-
-        # get the list of all possible values in the column
-        # but don't include None, since we are treating that as unknown.
-        self.column_types = list(set([getattr(x, self.carrier_summary)
-                                      for x in subjects.values()]))
-        self.column_types = [i for i in self.column_types if i is not None]
-        self.column_counters = {None: set()}
-        for ct in self.column_types:
-            self.column_counters[ct] = set([k for (k, v) in subjects.items() if
-                                            getattr(v, self.carrier_summary) == ct])
-
-
-    def format(self, row):
-        have_variant = set(row.variant_samples)
-        have_reference = set(row.HOM_REF_samples)
-        unknown = len(set(row.UNKNOWN_samples).union(self.column_counters[None]))
-        carrier_counts = []
-        for ct in self.column_types:
-            counts = len(self.column_counters[ct].intersection(have_variant))
-            carrier_counts.append(counts)
-        for ct in self.column_types:
-            counts = len(self.column_counters[ct].intersection(have_reference))
-            carrier_counts.append(counts)
-
-        carrier_counts.append(unknown)
-        carrier_counts = map(str, carrier_counts)
-        return '\t'.join([str(row.row[c]) for c in row.row] + carrier_counts)
-
-    def format_query(self, query):
-        return query
-
-    def predicate(self, row):
-        return True
-
-    def header(self, fields):
-        """ return a header for the row """
-        header_columns = self.column_types
-        if self.carrier_summary == "affected":
-            header_columns = self._rename_affected()
-        carriers = [x + "_carrier" for x in map(str, header_columns)]
-        noncarriers = [ x + "_noncarrier" for x in map(str, header_columns)]
-        fields += carriers
-        fields += noncarriers
-        fields += ["unknown"]
-        return "\t".join(fields)
-
-    def _rename_affected(self):
-        header_columns = []
-        for ct in self.column_types:
-            if ct == True:
-                header_columns.append("affected")
-            elif ct == False:
-                header_columns.append("unaffected")
-        return header_columns
-
-class TPEDRowFormat(RowFormat):
-
-    X_PAR_REGIONS = [(60001, 2699520), (154931044, 155260560)]
-    Y_PAR_REGIONS = [(10001, 2649520), (59034050, 59363566)]
-
-    name = "tped"
-    NULL_GENOTYPES = ["."]
-    PED_MISSING = ["0", "0"]
-    VALID_CHROMOSOMES = map(str, range(1, 23)) + ["X", "Y", "XY", "MT"]
-    POSSIBLE_HAPLOID = ["X", "Y"]
-
-    def __init__(self, args):
-        gq = GeminiQuery(args.db)
-        subjects = get_subjects(args, skip_filter=True)
-        # get samples in order of genotypes
-        self.samples = [gq.idx_to_sample_object[x] for x in range(len(subjects))]
-
-    def format(self, row):
-        VALID_CHROMOSOMES = map(str, range(1, 23)) + ["X", "Y", "XY", "MT"]
-        chrom = row['chrom'].split("chr")[1]
-        chrom = chrom if chrom in VALID_CHROMOSOMES else "0"
-        start = str(row.row['start'])
-        """end = str(row.row['end'])
-        ref = row['ref']
-        alt = row['alt']"""
-        geno = [re.split('\||/', x) for x in row.row['gts'].split(",")]
-        geno = [self._fix_genotype(chrom, start, genotype, self.samples[i].sex)
-                for i, genotype in enumerate(geno)]
-        genotypes = " ".join(list(flatten(geno)))
-        name = str(row['variant_id'])
-        return " ".join([chrom, name, "0", start, genotypes])
-
-    def format_query(self, query):
-        NEED_COLUMNS = ["chrom", "rs_ids", "start", "ref", "alt", "gts", "type", "variant_id"]
-        return ensure_columns(query, NEED_COLUMNS)
-
-    def predicate(self, row):
-        geno = [re.split("\||/", x) for x in row['gts']]
-        geno = list(flatten(geno))
-        num_alleles = len(set(geno).difference(self.NULL_GENOTYPES))
-        return num_alleles > 0 and num_alleles <= 2 and row['type'] != "sv"
-
-    def _is_haploid(self, genotype):
-        return len(genotype) < 2
-
-    def _has_missing(self, genotype):
-        return any([allele in self.NULL_GENOTYPES for allele in genotype])
-
-    def _is_heterozygote(self, genotype):
-        return len(genotype) == 2 and (genotype[0] != genotype[1])
-
-    def _in_PAR(self, chrom, start):
-        if chrom == "X":
-            for region in self.X_PAR_REGIONS:
-                if start > region[0] and start < region[1]:
-                    return True
-        elif chrom == "Y":
-            for region in self.Y_PAR_REGIONS:
-                if start > region[0] and start < region[1]:
-                    return True
-        return False
-
-    def _fix_genotype(self, chrom, start, genotype, sex):
-        """
-        the TPED format has to have both alleles set, even if it is haploid.
-        this fixes that setting Y calls on the female to missing,
-        heterozygotic calls on the male non PAR regions to missing and haploid
-        calls on non-PAR regions to be the haploid call for both alleles
-        """
-        if sex == "2":
-            # set female Y calls and haploid calls to missing
-            if self._is_haploid(genotype) or chrom == "Y" or self._has_missing(genotype):
-                return self.PED_MISSING
-            return genotype
-        if chrom in self.POSSIBLE_HAPLOID and sex == "1":
-            # remove the missing genotype calls
-            genotype = [x for x in genotype if x not in self.NULL_GENOTYPES]
-            # if all genotypes are missing skip
-            if not genotype:
-                return self.PED_MISSING
-            # heterozygote males in non PAR regions are a mistake
-            if self._is_heterozygote(genotype) and not self._in_PAR(chrom, start):
-                return self.PED_MISSING
-            # set haploid males to be homozygous for the allele
-            if self._is_haploid(genotype):
-                return [genotype[0], genotype[0]]
-
-        # if a genotype is missing or is haploid set it to missing
-        if self._has_missing(genotype) or self._is_haploid(genotype):
-            return self.PED_MISSING
-        else:
-            return genotype
-
-    def header(self, fields):
-        return None
-
-class JSONRowFormat(RowFormat):
-
-    name = "json"
-
-    def __init__(self, args):
-        pass
-
-    def format(self, row):
-        """Emit a JSON representation of a given row
-        """
-        return json.dumps(row.row)
-
-    def format_query(self, query):
-        return query
-
-    def predicate(self, row):
-        return True
-
-    def header(self, fields):
-        return None
-
-'''class VCFRowFormat(RowFormat):
-
-    name = "vcf"
-
-    def __init__(self, args):
-        self.gq = GeminiQuery(args.db)
-
-    def format(self, row):
-        """Emit a VCF representation of a given row
-
-           TODO: handle multiple alleles
-        """
-        # core VCF fields
-        vcf_rec = [row.row['chrom'], row.row['start'] + 1]
-        if row.row['vcf_id'] is None:
-            vcf_rec.append('.')
-        else:
-            vcf_rec.append(row.row['vcf_id'])
-        vcf_rec += [row.row['ref'], row.row['alt'], row.row['qual']]
-        if row.row['filter'] is None:
-            vcf_rec.append('PASS')
-        else:
-            vcf_rec.append(row.row['filter'])
-        vcf_rec += [row.row['info'], 'GT']
-
-        # construct genotypes
-        gts = list(row['gts'])
-        gt_types = list(row['gt_types'])
-        gt_phases = list(row['gt_phases'])
-        for idx, gt_type in enumerate(gt_types):
-            phase_char = '/' if not gt_phases[idx] else '|'
-            gt = gts[idx]
-            alleles = gt.split(phase_char)
-            if gt_type == HOM_REF:
-                vcf_rec.append('0' + phase_char + '0')
-            elif gt_type == HET:
-                # if the genotype is phased, need to check for 1|0 vs. 0|1
-                if gt_phases[idx] and alleles[0] != row.row['ref']:
-                    vcf_rec.append('1' + phase_char + '0')
-                else:
-                    vcf_rec.append('0' + phase_char + '1')
-            elif gt_type == HOM_ALT:
-                vcf_rec.append('1' + phase_char + '1')
-            elif gt_type == UNKNOWN:
-                vcf_rec.append('.' + phase_char + '.')
-
-        return '\t'.join([str(c) if c is not None else "." for c in vcf_rec])
-
-    def format_query(self, query):
-        return query
-
-    def predicate(self, row):
-        return True
-
-    def header(self, fields):
-        """Return the original VCF's header
-        """
-        try:
-            self.gq.run('select vcf_header from vcf_header')
-            return str(self.gq.next()).strip()
-        except:
-            sys.exit("Your database does not contain the vcf_header table. Therefore, you cannot use --header.\n")'''
 
 class GeminiRow(object):
 
@@ -454,7 +216,10 @@ class GeminiQuery(object):
     def run(self, query, gt_filter=None, show_variant_samples=False,
             variant_samples_delim=',', predicates=None,
             needs_genotypes=False, needs_genes=False,
-            show_families=False, sort_results=False, needs_sample_names=False, nr_cores = 1):
+            show_families=False, test_mode=False, 
+            needs_sample_names=False, nr_cores = 1,
+            start_time = -42, use_header = False,
+            exp_id="Oink", timeout=10.0, batch_size = 100):
         """
         Execute a query against a Gemini database. The user may
         specify:
@@ -466,14 +231,17 @@ class GeminiQuery(object):
         self.gt_filter = gt_filter
         #print self.query + '; gt-filter = %s \n' % gt_filter
         self.nr_cores = nr_cores
+        self.start_time = start_time
+        self.use_header = use_header
+        self.exp_id = exp_id
+        self.timeout = timeout
+        self.batch_size = batch_size
         if self._is_gt_filter_safe() is False:
             sys.exit("ERROR: unsafe --gt-filter command.")
-        '''if not self.gt_filter == None:
-            self.gt_filter = self.gt_filter.replace('==','=')'''
         
         self.show_variant_samples = show_variant_samples
         self.variant_samples_delim = variant_samples_delim
-        self.sort_results = sort_results
+        self.test_mode = test_mode
         self.needs_genotypes = needs_genotypes
         self.needs_vcf_columns = False
         if self.formatter.name == 'vcf':
@@ -574,63 +342,66 @@ class GeminiQuery(object):
                 sys.__stderr__.write(str(e) + "\n")
                 self.cluster.shutdown()
                 raise StopIteration
-            variant_names = []
-            het_names = []
-            hom_alt_names = []
-            hom_ref_names = []
-            unknown_names = []
-            info = None
-
-            if 'info' in self.report_cols:
-                info = compression.unpack_ordereddict_blob(row['info'])
-
-            fields = OrderedDict()
-
-            for col in self.report_cols:
-                if col == "*":
-                    continue
-                if not col == "info":
-                    fields[col] = row[col]
-                elif col == "info":
-                    fields[col] = self._info_dict_to_string(info)
-
-            if self.show_variant_samples or self.needs_sample_names:
-                
-                het_names = self._get_variant_samples(row['variant_id'], HET)
-                hom_alt_names = self._get_variant_samples(row['variant_id'], HOM_ALT)
-                hom_ref_names = self._get_variant_samples(row['variant_id'], HOM_REF)
-                unknown_names = self._get_variant_samples(row['variant_id'], UNKNOWN)
-                variant_names = het_names | hom_alt_names
-                
-                if self.show_variant_samples:
-                    fields["variant_samples"] = \
-                        self.variant_samples_delim.join(variant_names)
-                    fields["HET_samples"] = \
-                        self.variant_samples_delim.join(het_names)
-                    fields["HOM_ALT_samples"] = \
-                        self.variant_samples_delim.join(hom_alt_names)
-                    
-            if self.show_families:
-                families = map(str, list(set([self.sample_to_sample_object[x].family_id
-                                              for x in variant_names])))
-                fields["families"] = self.variant_samples_delim.join(families)
+            return self.row_2_GeminiRow(row)
             
-            gemini_row = GeminiRow(fields, variant_names, het_names, hom_alt_names,
-                                   hom_ref_names, unknown_names, info,
-                                   formatter=self.formatter)
+    def row_2_GeminiRow(self, row):
+        variant_names = []
+        het_names = []
+        hom_alt_names = []
+        hom_ref_names = []
+        unknown_names = []
+        info = None
 
-            if not all([predicate(gemini_row) for predicate in self.predicates]):
+        if 'info' in self.report_cols:
+            info = compression.unpack_ordereddict_blob(row['info'])
+
+        fields = OrderedDict()
+
+        for col in self.report_cols:
+            if col == "*":
                 continue
+            if not col == "info":
+                fields[col] = row[col]
+            elif col == "info":
+                fields[col] = _info_dict_to_string(info)
 
-            if not self.for_browser:
-                return gemini_row
-            else:
-                return fields
+        if self.show_variant_samples or self.needs_sample_names:
+                
+            het_names = self._get_variant_samples(row['variant_id'], HET)
+            hom_alt_names = self._get_variant_samples(row['variant_id'], HOM_ALT)
+            hom_ref_names = self._get_variant_samples(row['variant_id'], HOM_REF)
+            unknown_names = self._get_variant_samples(row['variant_id'], UNKNOWN)
+            variant_names = het_names | hom_alt_names
+                
+            if self.show_variant_samples:
+                fields["variant_samples"] = \
+                    self.variant_samples_delim.join(variant_names)
+                fields["HET_samples"] = \
+                    self.variant_samples_delim.join(het_names)
+                fields["HOM_ALT_samples"] = \
+                    self.variant_samples_delim.join(hom_alt_names)
+                    
+        if self.show_families:
+            families = map(str, list(set([self.sample_to_sample_object[x].family_id
+                                          for x in variant_names])))
+            fields["families"] = self.variant_samples_delim.join(families)
+            
+        gemini_row = GeminiRow(fields, variant_names, het_names, hom_alt_names,
+                               hom_ref_names, unknown_names, info,
+                               formatter=self.formatter)
+
+        if not all([predicate(gemini_row) for predicate in self.predicates]):
+            return None
+
+        if not self.for_browser:
+            return gemini_row
+        else:
+            return fields
             
     def _get_variant_samples(self, variant_id, gt_type):
         query = "SELECT sample_name from samples_by_variants_gt_type WHERE variant_id = %s AND gt_type = %s"
         self.session.row_factory = tuple_factory
-        return rows_as_set(self.session.execute(query, (variant_id, gt_type)))    
+        return async_rows_as_set(self.session, query % (variant_id, gt_type))    
 
     def _group_samples_by_genotype(self, gt_types):
         """
@@ -681,11 +452,72 @@ class GeminiQuery(object):
         return False
 
     def _execute_query(self):
-        if len(self.matches) == 0:
+        
+        n_matches = len(self.matches)
+        self.session.row_factory = ordered_dict_factory
+        query = "SELECT %s FROM %s" % (','.join(self.requested_columns + self.extra_columns), self.from_table)
+        error_count = 0
+        
+        if n_matches == 0:
+            
             print "No results!"
-            self.report_cols = []
-            self.result = iter([])
-        else:
+            time_taken = time.time() - self.start_time
+            
+        elif not self.test_mode:
+            
+            output_folder = self.exp_id + "_results"
+            if not os.path.exists(output_folder):
+                os.makedirs(output_folder)
+            output_path = output_folder + "/%s"
+            
+            if self.matches == "*":
+                
+                print "All rows match query."
+                query += " " + self.rest_of_query                
+                error_count += execute_async_blocking(self.session, query, output_path % 0, self.extra_columns, (), self.timeout)
+            
+            else:
+                
+                print "%d rows match query." % len(self.matches)
+                step = len(self.matches) / self.nr_cores
+                    
+                procs = []
+                conns = []
+                                       
+                for i in range(self.nr_cores):
+                    parent_conn, child_conn = Pipe()
+                    conns.append(parent_conn)
+                    p = Process(target=fetch_matches,
+                                args=(child_conn, i, output_path % i, query, self.from_table,\
+                                      self.get_partition_key(self.from_table), self.extra_columns,\
+                                      self.db_contact_points, self.keyspace, self.batch_size))
+                    procs.append(p)
+                    p.start()
+                    
+                for i in range(self.nr_cores):
+                    n = len(self.matches)
+                    begin = i*step + min(i, n % self.nr_cores)
+                    end = begin + step
+                    if i < n % self.nr_cores:
+                        end += 1  
+                    conns[i].send(self.matches[begin:end]) 
+                    
+                for i in range(self.nr_cores):
+                    errs = conns[i].recv()
+                    error_count += errs
+                    conns[i].close()
+                    procs[i].join()
+                
+            time_taken = time.time() - self.start_time
+                    
+            print "Query %s completed in %s s." % (self.exp_id, time_taken)
+            print "Query %s encountered %d errors" % (self.exp_id, error_count)
+                   
+        else: 
+            signal(SIGPIPE,SIG_DFL) 
+            '''
+                Test mode stuff: no extra prints, synchronous execution, sort results
+            '''
             try:
                 query = "SELECT %s FROM %s" % (','.join(self.requested_columns + self.extra_columns), self.from_table)
                 if self.matches != "*":
@@ -696,21 +528,32 @@ class GeminiQuery(object):
                         in_clause = "','".join(self.matches)            
                         query += " WHERE %s IN ('%s')" % (self.get_partition_key(self.from_table), in_clause)
                 query += " " + self.rest_of_query
-                self.session.row_factory = ordered_dict_factory
+                    
                 res = self.session.execute(query)  
-                if self.sort_results:
-                    if self.from_table == 'variants':
-                        res = sorted(res, key = lambda x: x['start'])   
-                    elif self.from_table == 'samples':
-                        res = sorted(res, key = lambda x: x['sample_id'])
-                      
+                if self.from_table == 'variants':
+                    res = sorted(res, key = lambda x: x['start'])   
+                elif self.from_table == 'samples':
+                    res = sorted(res, key = lambda x: x['sample_id'])
+                          
                 self.report_cols = filter(lambda x: not x in self.extra_columns, res[0].keys())
-                self.result = iter(res)
+                        
+                if self.use_header and self.header:
+                    print self.header
+                            
+                for row in res:
+                    print self.row_2_GeminiRow(row)  
+                        
+            except Exception as e:
+                sys.stderr.write(str(e))
+            finally:
+                time_taken = time.time() - self.start_time
+                
+        with open("querylog", 'a') as log:
+            log.write("2::%s;%s;%d\n" % (self.exp_id, time_taken, error_count))
+                
+    def set_report_cols(self, rep_cols):
+        self.report_cols = rep_cols
                 
-            except cassandra.protocol.SyntaxException as e:
-                print "Cassandra error: {0}".format(e)
-                sys.exit("The query issued (%s) has a syntax error." % query)
-
     def _apply_query(self):
         """
         Execute a query. Intercept gt* columns and
@@ -724,7 +567,13 @@ class GeminiQuery(object):
         
         self.matches = "*"
         if not self.where_exp is None:
-            self.matches = self.where_exp.evaluate(self.session, "*")
+            self.matches = list(self.where_exp.evaluate(self.session, "*"))
+        
+        mid_time = time.time()
+        
+        log = open("querylog", 'a')
+        log.write("1::%s;%s\n" % (self.exp_id, mid_time - self.start_time))
+        log.close()
 
         if self._query_needs_genotype_info():
             # break up the select statement into individual
@@ -735,10 +584,13 @@ class GeminiQuery(object):
         if self.show_families or self.show_variant_samples or self.needs_sample_names:
             if (not 'variant_id' in self.requested_columns) and (not "*" in self.requested_columns):
                 self.extra_columns.append('variant_id')
-        if self.sort_results and self.from_table == 'variants' and not 'start' in self.requested_columns:
+        if self.test_mode and self.from_table == 'variants' and not 'start' in self.requested_columns:
             self.extra_columns.append('start')
         self._execute_query()
         
+    def shutdown(self):
+        self.session.shutdown()
+        self.cluster.shutdown()
 
     def _get_matching_sample_ids(self, wildcard):
         
@@ -843,20 +695,21 @@ class GeminiQuery(object):
         where_clause = where_clause.replace('==','=')
         clauses = where_clause.split("and")
         
-        has_range_clause = False
         range_clauses = filter(lambda x: '<' in x or '>' in x, clauses)    
-        if len(range_clauses) > 1:
-            sys.exit("ERROR: only one range clause within single table possible")
-        elif len(range_clauses) == 1:
-            range_clause = range_clauses[0] 
-            has_range_clause = True
+            
+        range_col = None
+        for range_clause in range_clauses:
             i = 0
             for op in ["<", ">"]:
                 temp = range_clause.find(op)
                 if temp > -1:
                     i = temp
                     break
-            range_col = range_clause[0:i].strip()
+            col = range_clause[0:i].strip()
+            if range_col and (col != range_col):
+                sys.exit("ERROR: range clauses only possible on at most one column")
+            else:
+                range_col = col            
             
         eq_clauses = filter(lambda x: not ('<' in x or '>' in x), clauses)
         eq_clauses = map(lambda x: x.split('='), eq_clauses)
@@ -868,7 +721,7 @@ class GeminiQuery(object):
             if all(x in eq_columns for x in t.partition_key):
                 other_cols = filter(lambda x: not x in t.partition_key, eq_columns)
                 if all (x in t.clustering_key[:len(other_cols)] for x in other_cols):
-                    if has_range_clause:
+                    if range_col:
                         if range_col == t.clustering_key[len(other_cols)]:
                             return t.name
                     else:
@@ -1011,19 +864,8 @@ class GeminiQuery(object):
                 tokens_to_be_removed.add(token)
         
         for token in tokens_to_be_removed:
-            self.requested_columns.remove(token)
-            
-    def _info_dict_to_string(self, info):
-        """
-        Flatten the VCF info-field OrderedDict into a string,
-        including all arrays for allelic-level info.
-        """
-        if info is not None:
-            return ';'.join(['%s=%s' % (key, value) if not isinstance(value, list) \
-                             else '%s=%s' % (key, ','.join([str(v) for v in value])) \
-                             for (key, value) in info.items()])
-        else:
-            return None
+            self.requested_columns.remove(token)         
+    
 
     def _tokenize_query(self):
         tokens = list(flatten([x.split(",") for x in self.query.split(" ")]))
@@ -1053,6 +895,18 @@ def select_formatter(args):
                                   % (args.format, SUPPORTED_FORMATS))
     else:
         return SUPPORTED_FORMATS[args.format](args)
+    
+def _info_dict_to_string(info):
+    """
+    Flatten the VCF info-field OrderedDict into a string,
+    including all arrays for allelic-level info.
+    """
+    if info is not None:
+        return ';'.join(['%s=%s' % (key, value) if not isinstance(value, list) \
+                        else '%s=%s' % (key, ','.join([str(v) for v in value])) \
+                         for (key, value) in info.items()])
+    else:
+        return None
 
 
 def flatten(l):
@@ -1081,65 +935,128 @@ def fold(function, iterable, initializer=None):
     for x in it:
         accum_value = function(x, accum_value)
     return accum_value
+    
+class LoggedPagedResultHandler(object):
+    
+    def __init__(self, future, extra_columns, output_path):
+        self.error = None
+        self.finished_event = Event()
+        self.extra_columns = extra_columns
+        self.output_path = output_path
+        self.report_cols = None
+        self.future = future
+        self.future.add_callbacks(callback=self.handle_page, errback=self.handle_error)
 
-if __name__ == "__main__":
+    def handle_page(self, results):
+        
+        with open(self.output_path, 'a') as output:
+                    
+            for row in results:                
+                if not self.report_cols:
+                    self.report_cols = filter(lambda x: not x in self.extra_columns, row.keys())
+                    
+                gemini_row = barebones_row2geminiRow(row, self.report_cols)
+                if not gemini_row == None:
+                    output.write("%s\n" % gemini_row)
 
-    db = sys.argv[1]
+        if self.future.has_more_pages:
+            self.future.start_fetching_next_page()
+        else:
+            self.finished_event.set()
 
-    gq = GeminiQuery(db)
+    def handle_error(self, exc):
+        self.error = exc
+        sys.stderr.write(str(type(exc)) + "\n")
+        self.finished_event.set()
 
-    print "test a basic query with no genotypes"
-    query = "select chrom, start, end from variants limit 5"
-    gq.run(query)
-    for row in gq:
-        print row
+def fetch_matches(conn, proc_n, output_path, query, table, partition_key, extra_columns, db, keyspace, b_size):
+        
+    start = time.time()
+    
+    matches = conn.recv()
+    n_matches = len(matches)
+    
+    error_count = 0
+    
+    if cpu_count() > 8:            
+        nap = 1*(proc_n % 11)
+        sleep(nap)
+    
+    session = connect_or_fail(db, keyspace)
+    if not session:
+        return       
+    
+    if cpu_count() > 8:            
+        nap = 1*(11 - (proc_n % 11))
+        sleep(nap)
+    
+    batch_size = b_size       
+    in_clause = ','.join(list(repeat("?",batch_size))) 
+    batch_query = query + " WHERE %s IN (%s)" % (partition_key, in_clause)
+                
+    prepared_query = session.prepare(batch_query)
+    
+    print "setup ready in %.2f s" % (time.time() - start)
+                
+    for i in range(n_matches / batch_size):
+        batch = matches[i*batch_size:(i+1)*batch_size]
+        error_count += execute_async_blocking(session, prepared_query, output_path, extra_columns, batch)             
+                
+    if n_matches % batch_size != 0:
+        leftovers_batch = matches[(n_matches / batch_size)*batch_size:]
+        if table != 'samples':
+            in_clause = ",".join(map(str, leftovers_batch))            
+            leftover_query = query + " WHERE %s IN (%s)" % (partition_key, in_clause)
+        else:
+            in_clause = "','".join(leftovers_batch)            
+            leftover_query = query + " WHERE %s IN ('%s')" % (partition_key, in_clause)
+        error_count += execute_async_blocking(session, leftover_query, output_path, extra_columns)      
+    
+    conn.send(error_count)
+    conn.close()
+    session.shutdown()
+    
+def execute_async_blocking(session, query, output_path, extra_columns, pars=(),timeout=13.7):
+    future = session.execute_async(query,pars,timeout)          
+    handler = LoggedPagedResultHandler(future, extra_columns, output_path)
+    handler.finished_event.wait()
+    if handler.error:
+        return 1
+    else:
+        return 0
+    
+def connect_or_fail(db, keyspace, retry = 0):
+    
+    try:
+        cluster = Cluster(db)
+        session = cluster.connect(keyspace)
+        session.row_factory = ordered_dict_factory
+        return session
+    except Exception:
+        if retry < 10:
+            return connect_or_fail(db, keyspace, retry + 1)
+        else:
+            return None    
+           
+def barebones_row2geminiRow(row, report_cols):
+    
+    info = None
 
-    print "test a basic query with no genotypes using a header"
-    query = "select chrom, start, end from variants limit 5"
-    gq.run(query)
-    print gq.header
-    for row in gq:
-        print row
+    if 'info' in report_cols:
+        info = compression.unpack_ordereddict_blob(row['info'])
 
-    print "test query that selects a sample genotype"
-    query = "select chrom, start, end, gts.NA20814 from variants limit 5"
-    gq.run(query)
-    for row in gq:
-        print row
+    fields = OrderedDict()
 
-    print "test query that selects a sample genotype and uses a header"
-    query = "select chrom, start, end, gts.NA20814 from variants limit 5"
-    gq.run(query)
-    print gq.header
-    for row in gq:
-        print row
+    for col in report_cols:
+        if col == "*":
+            continue
+        if not col == "info":
+            fields[col] = row[col]
+        elif col == "info":
+            fields[col] = _info_dict_to_string(info)
+            
+    gemini_row = GeminiRow(fields, [], [], [], [], [], info)
 
-    print "test query that selects and _filters_ on a sample genotype"
-    query = "select chrom, start, end, gts.NA20814 from variants limit 50"
-    db_filter = "gt_types.NA20814 == HET"
-    gq.run(query, db_filter)
-    for row in gq:
-        print row
+    return gemini_row
 
-    print "test query that selects and _filters_ on a sample genotype and uses a filter"
-    query = "select chrom, start, end, gts.NA20814 from variants limit 50"
-    db_filter = "gt_types.NA20814 == HET"
-    gq.run(query, db_filter)
-    print gq.header
-    for row in gq:
-        print row
-
-    print "test query that selects and _filters_ on a sample genotype and uses a filter and a header"
-    query = "select chrom, start, end, gts.NA20814 from variants limit 50"
-    db_filter = "gt_types.NA20814 == HET"
-    gq.run(query, db_filter)
-    print gq.header
-    for row in gq:
-        print row
-
-    print "demonstrate accessing individual columns"
-    query = "select chrom, start, end, gts.NA20814 from variants limit 50"
-    db_filter = "gt_types.NA20814 == HET"
-    gq.run(query, db_filter)
-    for row in gq:
-        print row['chrom'], row['start'], row['end'], row['gts.NA20814']
+        
\ No newline at end of file
