@@ -173,16 +173,12 @@ class GeminiLoader(object):
         self.leftover_gts = blist([])
         buffer_count = 0
         self.skipped = 0
-        #extra_file, extraheader_file = geminicassandra.get_extra_files(self.args.db)
-        #extra_headers = {}
         self.counter = 0
         start_time = time.time()
         interval_start = time.time()
         variants_gts_timer = 0
         log_file = open("loading_logs/%s.csv" % str(os.getpid()), "w")
         self.time_out_log = open("loading_logs/%s.err" % str(os.getpid()), "w")
-        #with open(extra_file, "w") as extra_handle:
-            # process and load each variant in the VCF file
         vars_inserted = 0
         for var in self.vcf_reader:
             if self.args.passonly and (var.FILTER is not None and var.FILTER != "."):
@@ -239,11 +235,7 @@ class GeminiLoader(object):
                 variants_gts_timer = 0
             self.v_id += 1
             self.counter += 1
-        '''if extra_headers:
-            with open(extraheader_file, "w") as out_handle:
-                out_handle.write(json.dumps(extra_headers))
-        else:
-            os.remove(extra_file)'''
+            
         # final load to the database
         self.v_id -= 1
         
@@ -286,7 +278,7 @@ class GeminiLoader(object):
                 try:
                     old_future.result()
                     del retries[old_i]
-                except cassandra.WriteTimeout:
+                except cassandra.WriteTimeout, cassandra.OperationTimedOut:
                     if retries[old_i] < retry_threshold:
                         if retries[old_i] == 0:
                             self.write_to_timeoutlog("1::%s;%s;%s;%s;%s\n" % \
@@ -316,13 +308,8 @@ class GeminiLoader(object):
                         self.leftover_depths.append(depth_buf[old_i])
                         self.leftover_gts.append(gt_buffer[old_i])
                         self.write_to_timeoutlog("4::%s;%s;%s;%s;%s\n" % \
-                                                (types_buf[old_i][0], types_buf[old_i][1], types_buf[old_i][2], depth_buf[old_i][2], len(gt_buffer[old_i][2])))
-                        
-                except cassandra.OperationTimedOut as e:
-                    self.write_to_timeoutlog("39::%s" % str(e))
-                    stderr.write("Proc %s: OperationTimedOut - goodbye\n")
-                    sys.exit()
-                
+                                                (types_buf[old_i][0], types_buf[old_i][1], types_buf[old_i][2], depth_buf[old_i][2], len(gt_buffer[old_i][2])))          
+                       
             future = self.execute_var_gts_batch(types_buf[i], depth_buf[i], gt_buffer[i])
             futures.put_nowait((i, future))
             retries[i] = 0
@@ -339,7 +326,7 @@ class GeminiLoader(object):
     def execute_concurrent_with_retry(self, insert_query, contents, retry=0):
         try:
             execute_concurrent_with_args(self.session, insert_query, contents)
-        except cassandra.WriteTimeout:
+        except cassandra.WriteTimeout, cassandra.OperationTimedOut:
             self.write_to_timeoutlog("5::%d\n" % contents[0][0])   
             self.execute_concurrent_with_retry(insert_query, contents, retry)
         except cassandra.InvalidRequest as e:
@@ -987,7 +974,7 @@ def load(parser, args):
     if args.anno_type not in ['snpEff', 'VEP', None]:
         parser.print_help()
         exit("\nERROR: Unsupported selection for -t\n")
-
+        
     # collect of the the add'l annotation files
     annotations.load_annos( args )
 
