@@ -380,6 +380,18 @@ def main():
                               action='store_true',
                               help='Sort variants by start, samples by sample_id. ONLY TO BE USED FOR UNIT TESTS',
                               default=False)
+    parser_query.add_argument('--exp_id',
+                              dest='exp_id',
+                              default='hoebahoeba')
+    parser_query.add_argument('-timeout',
+                              dest='timeout',
+                              default=10.0,
+                              type=float)
+    parser_query.add_argument('-batch_size',
+                              dest='batch_size',
+                              default=50,
+                              type=int)
+    
     def query_fn(parser, args):
         import gemini_query
         gemini_query.query(parser, args)
