@@ -3,17 +3,17 @@
 # 1. Test the samples table
 ####################################################################
 echo "    query.t01...\c"
-echo "1094PC0005	1	0	0	0	-9	-9
-1094PC0009	2	0	0	0	-9	-9
-1094PC0012	3	0	0	0	-9	-9
-1094PC0013	4	0	0	0	-9	-9
-1094PC0016	5	0	0	0	-9	-9
-1094PC0017	6	0	0	0	-9	-9
-1094PC0018	7	0	0	0	-9	-9
-1094PC0019	8	0	0	0	-9	-9
-1094PC0020	9	0	0	0	-9	-9
-1094PC0021	10	0	0	0	-9	-9" > exp
-geminicassandra query -q "select * from samples" --test-mode -db $cassandra_ips -ks test_query_db | head > obs
+echo "1094PC0005	1	0	0	0
+1094PC0009	2	0	0	0
+1094PC0012	3	0	0	0
+1094PC0013	4	0	0	0
+1094PC0016	5	0	0	0
+1094PC0017	6	0	0	0
+1094PC0018	7	0	0	0
+1094PC0019	8	0	0	0
+1094PC0020	9	0	0	0
+1094PC0021	10	0	0	0" > exp
+geminicassandra query -q "select name, sample_id, family_id, maternal_id, paternal_id from samples" --test-mode -db $cassandra_ips -ks test_query_db | head > obs
 check obs exp
 rm obs exp
 
@@ -31,7 +31,7 @@ chr1	69427	69428	T	G
 chr1	69510	69511	A	G
 chr1	69760	69761	A	T
 chr1	69870	69871	G	A" > exp
-geminicassandra query -q "select chrom, start, end, ref, alt from variants" --test-mode -db $cassandra_ips -ks test_query_db | head \
+geminicassandra query -q "select chrom, start, end, ref, alt from variants" --test-mode -db $cassandra_ips -ks test_query_db --exp_id query2 | head \
        > obs
 check obs exp
 rm obs exp
@@ -52,7 +52,7 @@ chr1	1219533	1219536	GTT	G	SCNN1D
 chr1	1219555	1219558	GTT	G	SCNN1D" > exp
 geminicassandra query -q "select chrom, start, end, ref, alt, gene \
                  from variants \
-                 where gene == 'SCNN1D'" --test-mode -db $cassandra_ips -ks test_query_db | head \
+                 where gene == 'SCNN1D'" --test-mode -db $cassandra_ips -ks test_query_db --exp_id query3 | head \
 	> obs
 check obs exp
 rm obs exp
