@@ -12,7 +12,7 @@ T/T	C/C	C/T	C/T
 T/T	T/T	C/C	C/C
 C/T	C/C	C/C	C/C
 ./.	C/C	C/C	./." > exp
-geminicassandra query -q "select (gts).(*)from variants" -db $cassandra_ips -ks extended_ped_db > obs
+geminicassandra query -q "select (gts).(*)from variants" --test-mode -db $cassandra_ips -ks extended_ped_db > obs
 check obs exp
 rm obs exp
 
@@ -86,7 +86,7 @@ echo "    wildcard.t6...\c"
 echo "chrom	start	end	ref	alt	gts_m10478	gts_m10500
 chr10	135336655	135336656	G	A	A/A	./." > exp
 geminicassandra query --header -q "select chrom, start, end, ref, alt, (gts).(phenotype=='2') from variants" \
-             --gt-filter "[gt_types].[phenotype=='2'].[!=HOM_REF].[all] && gts.M10478 =='A/A'" -db $cassandra_ips -ks extended_ped_db > obs
+             --gt-filter "[gt_types].[phenotype=='2'].[!=HOM_REF].[all] && gts.M10478 =='A/A'" --test-mode -db $cassandra_ips -ks extended_ped_db > obs
 check obs exp
 rm obs exp
 
@@ -209,7 +209,7 @@ echo "    wildcard.t15...\c"
 echo "chrom	start	end	ref	alt	gts_m10475	gts_m128215	gts_m10500	gts_m10478
 chr10	126678091	126678092	G	A	G/G	G/A	G/G	G/G" > exp
 geminicassandra query --header -q "select chrom, start, end, ref, alt, (gts).(*) from variants" \
-             --gt-filter "[gt_types].[*].[==    HOM_ALT].[  count   !=2] && gts.M10478 =='G/G'" -db $cassandra_ips -ks extended_ped_db > obs
+             --gt-filter "[gt_types].[*].[==    HOM_ALT].[  count   !=2] && gts.M10478 =='G/G'" --test-mode -db $cassandra_ips -ks extended_ped_db > obs
 check obs exp
 rm obs exp
 
@@ -219,7 +219,7 @@ rm obs exp
 echo "    wildcard.t16...\c"
 echo "Unsupported wildcard operation: (). Exiting." > exp
 geminicassandra query --header -q "select chrom, start, end, ref, alt, (gts).(*) from variants" \
-             --gt-filter "[gt_types].[*].[==HOM_ALT].[]" -db $cassandra_ips -ks extended_ped_db 2> obs
+             --gt-filter "[gt_types].[*].[==HOM_ALT].[]" --test-mode -db $cassandra_ips -ks extended_ped_db 2> obs
 check obs exp
 rm obs exp
 
@@ -229,7 +229,7 @@ rm obs exp
 echo "    wildcard.t17...\c"
 echo "Unsupported wildcard operation: (amy). Exiting." > exp
 geminicassandra query --header -q "select chrom, start, end, ref, alt, (gts).(*) from variants" \
-             --gt-filter "[gt_types].[*].[==HOM_ALT].[amy]" -db $cassandra_ips -ks extended_ped_db 2> obs
+             --gt-filter "[gt_types].[*].[==HOM_ALT].[amy]" --test-mode -db $cassandra_ips -ks extended_ped_db 2> obs
 check obs exp
 rm obs exp
 
@@ -239,7 +239,7 @@ rm obs exp
 echo "    wildcard.t18...\c"
 echo "Wildcard filter should consist of 4 elements. Exiting." > exp
 geminicassandra query --header -q "select chrom, start, end, ref, alt, (gts).(*) from variants" \
-             --gt-filter "[gt_types].[*].[==HOM_ALT]" -db $cassandra_ips -ks extended_ped_db 2> obs
+             --gt-filter "[gt_types].[*].[==HOM_ALT]" --test-mode -db $cassandra_ips -ks extended_ped_db 2> obs
 check obs exp
 rm obs exp
 
@@ -264,7 +264,7 @@ rm obs exp
 echo "    wildcard.t20...\c"
 echo "No results!" > exp
 geminicassandra query --header -q "select chrom, start, end, ref, alt, gene, (gts).(*) from variants" \
-             --gt-filter "([gt_types].[phenotype=='1'].[!=HOM_REF].[all] && [gt_types].[phenotype=='2'].[==HOM_REF].[all])" -db $cassandra_ips -ks extended_ped_db > obs
+             --gt-filter "([gt_types].[phenotype=='1'].[!=HOM_REF].[all] && [gt_types].[phenotype=='2'].[==HOM_REF].[all])" --test-mode -db $cassandra_ips -ks extended_ped_db > obs
 check obs exp
 rm obs exp
 
